@@ -10,6 +10,7 @@ use AsyncAws\Core\Credentials\CacheProvider;
 use AsyncAws\Core\Credentials\ChainProvider;
 use AsyncAws\Core\Credentials\CredentialProvider;
 use AsyncAws\Core\EndpointDiscovery\EndpointCache;
+use AsyncAws\Core\EndpointDiscovery\EndpointInterface;
 use AsyncAws\Core\Exception\InvalidArgument;
 use AsyncAws\Core\Exception\LogicException;
 use AsyncAws\Core\Exception\RuntimeException;
@@ -47,7 +48,7 @@ abstract class AbstractApi
     private $credentialProvider;
 
     /**
-     * @var Signer[]
+     * @var array<string, Signer>
      */
     private $signers;
 
@@ -67,7 +68,7 @@ abstract class AbstractApi
     private $endpointCache;
 
     /**
-     * @param Configuration|array $configuration
+     * @param Configuration|array<Configuration::OPTION_*, string|null> $configuration
      */
     public function __construct($configuration = [], ?CredentialProvider $credentialProvider = null, ?HttpClientInterface $httpClient = null, ?LoggerInterface $logger = null)
     {
@@ -151,7 +152,7 @@ abstract class AbstractApi
             $request->setHeader('content-length', (string) $length);
         }
 
-        // Some servers (like testing Docker Images) does not supports `Transfer-Encoding: chunked` requests.
+        // Some servers (like testing Docker Images) does not support `Transfer-Encoding: chunked` requests.
         // The body is converted into string to prevent curl using `Transfer-Encoding: chunked` unless it really has to.
         if (($requestBody = $request->getBody()) instanceof StringStream) {
             $requestBody = $requestBody->stringify();
@@ -178,7 +179,7 @@ abstract class AbstractApi
     }
 
     /**
-     * @return callable[]
+     * @return array<string, callable(string, string): Signer>
      */
     protected function getSignerFactories(): array
     {
@@ -229,13 +230,12 @@ abstract class AbstractApi
     /**
      * Build the endpoint full uri.
      *
-     * @param string  $uri    or path
-     * @param array   $query  parameters that should go in the query string
-     * @param ?string $region region provided by the user in the `@region` parameter of the Input
+     * @param string                $uri    or path
+     * @param array<string, string> $query  parameters that should go in the query string
+     * @param ?string               $region region provided by the user in the `@region` parameter of the Input
      */
     protected function getEndpoint(string $uri, array $query, ?string $region): string
     {
-        /** @var string $region */
         $region = $region ?? ($this->configuration->isDefault('region') ? null : $this->configuration->get('region'));
         if (!$this->configuration->isDefault('endpoint')) {
             /** @var string $endpoint */
@@ -256,18 +256,26 @@ abstract class AbstractApi
         }
 
         $endpoint .= $uri;
-        if (empty($query)) {
+        if ([] === $query) {
             return $endpoint;
         }
 
-        return $endpoint . (false === strpos($endpoint, '?') ? '?' : '&') . http_build_query($query);
+        return $endpoint . (false === strpos($endpoint, '?') ? '?' : '&') . http_build_query($query, '', '&', \PHP_QUERY_RFC3986);
     }
 
+    /**
+     * @return EndpointInterface[]
+     */
     protected function discoverEndpoints(?string $region): array
     {
         throw new LogicException(sprintf('The Client "%s" must implement the "%s" method.', \get_class($this), 'discoverEndpoints'));
     }
 
+    /**
+     * @param array<string, string> $query
+     *
+     * @return string
+     */
     private function getDiscoveredEndpoint(string $uri, array $query, ?string $region, bool $usesEndpointDiscovery, bool $requiresEndpointDiscovery)
     {
         if (!$this->configuration->isDefault('endpoint')) {
@@ -303,13 +311,18 @@ abstract class AbstractApi
             }
         }
 
-        return $endpoint;
+        $endpoint .= $uri;
+        if (empty($query)) {
+            return $endpoint;
+        }
+
+        return $endpoint . (false === strpos($endpoint, '?') ? '?' : '&') . http_build_query($query);
     }
 
     /**
      * @param ?string $region region provided by the user in the `@region` parameter of the Input
      */
-    private function getSigner(?string $region)
+    private function getSigner(?string $region): Signer
     {
         /** @var string $region */
         $region = $region ?? ($this->configuration->isDefault('region') ? null : $this->configuration->get('region'));
